{% load telemeta_tags %}
{% load i18n %}

{% if object_list %}

<table class="listing">
<tr>
    <th class="highlight" width="15%">{% trans "Title" %}</th>
    <th width="5%">{% trans "Digitized" %}</th>
    <th>{% trans "Description" %}</th>
    <th width="15%">{% trans "Code" %}</th>

</tr>
{% for resource in object_list %}
<tr {% if not forloop.counter0|divisibleby:"2" %}class="odd"{% endif %}>
    <td class="highlight">
        <a href="{% url "telemeta-resource-detail" type resource.public_id %}">{{ resource.title }}</a>
    </td>
    <td>{% if resource.has_mediafile %}
       <center><span class="glyphicon glyphicon-volume-up" style="font-size: 1.3em;"></span></center>
      {% endif %}
    </td>
    <td>{{ resource.descriptions }}</td>
    <td>{{ resource.code }}</td>

</tr>
{% endfor %}
</table>

{% else %}
    <p>{% trans "No resource" %}</p>
{% endif %}

