{% extends "telemeta/mediaitem_detail.html" %}
{% load telemeta_tags %}
{% load i18n %}


{% block stylesheets %}
{{ block.super }}
    <style type="text/css">
        #rightcol {
            width: {{width}}px;
        }
        .ts-skin-lab .ts-player .ts-wave {
            height: {{height}}px;
        }
    </style>
{% endblock %}

{% block title %}{% endblock %}
{% block title_buttons %}{% endblock %}

{% block layout %}
{% block content %}
<div>
{% if item.file %}
    {% if access or user.is_staff %}
    <div id="rightcol" style="{% if LANGUAGE_BIDI %}float: right;{% else %}float: left;{% endif %}padding-bottom:0;">
        <div id="player_minimized" class="ts-skin-lab">
            <div class="wazing"></div>
            <div id="player" class="ts-player">
            </div>
        </div>
       <div>
        <span style="font-size:65%; float:left">{% organization %} - Item : <a href="{% url "telemeta-item-detail" item.public_id %}" target="_blank">{% if item.code %}{{ item.code }}{% else %}{{ item.old_code }}{% endif %}</a></span>
        <span style="font-size:65%; float:right"><a href="http://telemeta.org" target="_blank">Telemeta</a> powered</span>
       </div>
    </div>
    {% endif %}
{% endif %}
</div>

{% endblock content%}
{% endblock layout %}

{% block footer %}{% endblock %}
