{% load telemeta_tags %}
{% load i18n %}

{% if children %}

{% if hits %}
<p class="pagination">
{% blocktrans %}{{ resource.children_type|capitalize }} {{ first_on_page }} to {{ last_on_page }} on {{ hits }}{% endblocktrans %}
| Pages : {% if pages == 1 %}1{% else %}{% if is_paginated %}{% load paginator %}{% paginator 5 %}{% endif %}{% endif %}
</p>
{% endif %}

<table class="listing">
{% for child in children %}
{% if child.code %}
<tr {% if not forloop.counter0|divisibleby:"2" %}class="odd"{% endif %}>
    <td class="highlight">
        <a href="{% url "telemeta-collection-epub" child.public_id %}">{{ child.title }}</a>
    </td>
    <td>
       <center><a href="{% url "telemeta-collection-epub" child.public_id %}">
        <button type="button" class="btn btn-default">
            <span class="glyphicon glyphicon-book"></span> {% trans "Download" %}
        </button>
        </a>
        </center>
    </td>
</tr>
{% endif %}
{% endfor %}
</table>

{% else %}
    <p>{% trans "No resource" %}</p>

{% endif %}
