{% extends "telemeta/registration/registration_base.html" %}
{% load i18n %}
{% block title %}{% trans "Confirm password reset" %}{% endblock %}
{% block content %}
{% trans "Enter your new password below to reset your password:" %}
<form method="post" action="">{% csrf_token %}
<table>
    {{ form.as_table }}
    <tr><td></td><td><input type="submit" value="{% trans "Set password" %}"/></td></tr>
</table>
</form>
{% endblock %}
