@namespace EPUB "http://www.idpf.org/2007/ops";

body {
    font-family: Cambria, Liberation Serif, Bitstream Vera Serif, Georgia, Times, Times New Roman, serif;
}

.title {
    padding-top : 18%;
    page-break-after:always;
}

h2 {
    font-family : sans-serif;
    text-align: left;
    font-size:110%;
    font-weight: bold;
}

h3 {
    text-align: left;
    font-size: 140%;
    margin-top: 0px;
    font-weight: bold;
    color: #2B90AB;
}

p {
    text-align: left;
    font-size: 0.8em;
    margin-top: 0px;
    font-weight: normal;
}

ol {
    list-style-type: none;
}

ol > li:first-child {
    margin-top: 0.3em;
}

nav[epub|type~='toc'] > ol > li > ol  {
    list-style-type:square;
}

nav[epub|type~='toc'] > ol > li > ol > li {
    margin-top: 0.3em;
}

.item {
    page-break-before: always;
}

.item-image {
    text-align: center;
}

.item-player {
    width: 100%;
    page-break-after: avoid;
}

img {
    text-align: center;
    width: 50%;
    height: auto;
}

.last-page {
    padding-top : 18%;
    page-break-before: always;
    text-align: center;
}

.error {
    color: red;
}
