# -*- coding: utf-8 -*-
# Copyright (C) 2007 Samalyse SARL
# Copyright (C) 2008-2011 Parisson SARL

# This file is part of Telemeta.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author: Olivier Guilyardi <olivier@samalyse.com>
#         Guillaume Pellerin <yomguy@parisson.com>


from identifier import *
from location import *
from instrument import *
from enum import *
from system import *
from query import *
from dublincore import *
from language import *
from format import *
from identifier import *
from fonds import *
from corpus import *
from collection import *
from item import *
from resource import *
from playlist import *

