{% extends "telemeta/registration/registration_base.html" %}
{% load i18n %}
{% block title %}{% trans "Activation complete" %}{% endblock %}
{% block content %}
{% url 'auth_login' as auth_login_url %}
{% blocktrans %}
Thanks, activation complete!  You may now <a href='{{ auth_login_url }}'>login</a> using the username and password you set at registration.
{% endblocktrans %}
{% endblock %}


