{% extends "telemeta/base.html" %}
{% load telemeta_tags %}
{% load i18n %}

{% block stylesheets %}
{{ block.super }}
<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}telemeta/css/admin.css" />
{% endblock %}

{% block title %}
<h1><img src="{{ STATIC_URL }}telemeta/images/admin_red.png" style="vertical-align:middle" /> <a href="{% url "telemeta-admin-general" %}">{% trans "Administration" %}</a></h1>
{% endblock %}

 <li>{% trans "General" %}</a></li>

{% block content %}

<div class="tabcontents">
    {% block tabcontents %}
    {% endblock %}
</div>

{% endblock %}
