{% load telemeta_tags %}
{% load i18n %}

<link rel="stylesheet" type="text/css" href="style/epub.css" />

<!-- <h2>{% trans 'Copyright' %}</h2> #} -->

<p>Vous trouverez dans ce « livret sons » au format ePub la collection complète des exemples sonores{% if mode_single %} du {{ title }}{% endif %} de l’ouvrage <i>Écoute musicale et acoustique</i> de Michèle Castellengo, paru aux Éditions Eyrolles.</p>

<p>
Conception : Michèle Castellengo<br/>
Réalisation : Parisson<br/>
</p>

<p>
(c) Groupe Eyrolles, 2015<br/>
Reproduction interdite sans autorisation de l’éditeur.
</p>

<!--
<p>
Cette oeuvre, création, site ou texte est sous licence Creative Commons Attribution - Pas d'Utilisation Commerciale - Pas de Modification 4.0 International. Pour accéder à une copie de cette licence, merci de vous rendre à l'adresse suivante http://creativecommons.org/licenses/by-nc-nd/4.0/ ou envoyez un courrier à Creative Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.
</p>
-->
