{% extends "telemeta/registration/registration_base.html" %}
{% load i18n %}
{% load telemeta_tags %}
{% load teleforma_tags %}

{% block title %}<center>{% trans "Registration" %} - {% description %}</center>{% endblock %}

{% block content %}
<center>
<div class="register">
Vous venez de réaliser avec succès votre préinscription à la formation estivale du Pré-Barreau.
<br><br>

Afin de valider votre inscription, nous vous invitons à imprimer le formulaire ci-dessous et à nous le retourner sous huitaine, accompagné du règlement (+ photocopie émetteur) et des photos d’identité à l’adresse suivante :
<br><br>

LE PRE-BARREAU<br>
Service inscription<br>
3, rue de Nesle<br>
75006 Paris
<br><br><br>

<a href="{{ register_doc_print.file.url }}" class="component_icon button" id="action_green" target="_blank"><img src="{{STATIC_URL}}telemeta/images/download.png" alt="" style="vertical-align:middle" />&nbsp;{% trans "Download" %}</a>

</center>
</div>

{% endblock %}


