{% extends "telemeta/registration/registration_base.html" %}
{% load i18n %}
{% block title %}{% trans "Reset password" %}{% endblock %}
{% block content %}{% blocktrans %}
Forgot your password?  Enter your email in the form below and we'll send you
instructions for creating a new one.{% endblocktrans %}
<br><br>
<form method='post' id="_loginForm" action=''>{% csrf_token %}
<table>
    {{ form }}
    <tr><td></td><td><br>
    <a href="#" onclick="$('#_loginForm').submit();" style="float: left;">
      <button type="button" class="btn btn-default">
        <span class="glyphicon glyphicon-log-in"></span> {% trans "Reset password" %}
      </button>
    </a>


    </td></tr>
</table>
</form>
{% endblock %}
