{% extends "postman/base_folder.html" %}
{% load i18n %}
{% block pm_folder_title %}{% trans "Sent Messages" %}{% endblock %}
{% block pm_undelete_button %}{% endblock %}
{% block pm_sender_header %}{% endblock %}
{% block pm_date %}{% trans "Sent" %}{% endblock %}
{% block pm_sender_cell %}{% endblock %}
