{% extends "telemeta/registration/registration_base.html" %}
{% load i18n %}
{% block title %}{% trans "Password reset complete" %}{% endblock %}
{% block content %}{% blocktrans %}
Your password has been reset!  You may now <a href="{{ login_url }}">log in</a>.
{% endblocktrans %}{% endblock %}
