{% extends "telemeta/resource_detail.html" %}
{% load i18n %}

{% block search %}
{% endblock search %}

{% block rightcol %}
{% endblock rightcol %}

{% block infos %}
<script>
$(document).ready(function() {
    $(this).keydown(function(e) {
        if (e.keyCode == '13') {
            $("#_loginForm").submit();
        }
    });
});
</script>


<div class="intro">
{% trans "Pour télécharger les livrets-sons au format EPUB3, merci de fournir le premier mot de la page 411 du livre." %}
</div>

<div style="background-color: white; align: center; padding: 1em;">

<form id="_loginForm" method="post" action="">{% csrf_token %}
    {% for message in messages %}
    <span class="login-error">{{ message }}</span>
    {% endfor %}

    {{ form.as_p }}

<a href="#" onclick="$('#_loginForm').submit();" style="float: left;">
  <button type="button" class="btn btn-default">
    <span class="glyphicon glyphicon-log-in"></span> {% trans "Envoyer" %}
  </button>
</a>

</form>
<br/><br/>
</div>
{% endblock infos %}

{% block dublincore %}
{% endblock dublincore %}