{% extends "telemeta/registration/registration_base.html" %}
{% load i18n %}
{% block title %}{% if account %}{% trans "Activation complete" %}{% else %}{% trans "Activation problem" %}{% endif %}{% endblock %}
{% block content %}
{% url 'auth_login' as auth_login_url %}
{% if account %}
{% blocktrans %}
Thanks {{ account }}, activation complete!
You may now <a href='{{ auth_login_url }}'>login</a> using the username and password you set at registration.
{% endblocktrans %}
{% else %}
{% blocktrans %}Oops &ndash; it seems that your activation key is invalid.  Please check the url again.{% endblocktrans %}
{% endif %}
{% endblock %}
