{% extends "telemeta/mediaitem_detail.html" %}
{% load telemeta_tags %}
{% load i18n %}

{% if item %}

{% block infos %}
{% with item|to_dublincore as resource %}
{% include "telemeta/inc/dublincore.html" %}
{% endwith %}
{% endblock %}

    {% block dublincore %}
    <a href="{% url "telemeta-item-detail" item.public_id %}" style="float:left;margin-top:0.5em;margin-bottom:1em">
      <button type="button" class="btn btn-default">
         <span class="glyphicon glyphicon-arrow-left"></span> {% trans "Normal View" %}
      </button>
    </a>
    {% endblock dublincore %}

{% else %}
    <p>{% trans "No such item" %}</p>
{% endif %}

{% block delete %}

{% if user.is_authenticated and perms.telemeta.delete_mediaitem %}
     <a href="#" onclick="if(confirm(gettrans('delete the item permanently?'))){window.location.href='{% url "telemeta-item-delete" item.public_id %}';};return false;"
        style="float:right;margin-top:0.5em;margin-bottom:1em">
          <button type="button" class="btn btn-default">
        <span class="glyphicon glyphicon-trash"></span> {% trans "Delete" %}
      </button>
      </a>
{% endif %}
{% endblock %}


{% block related %}
{% endblock related %}
