{% extends "telemeta/base.html" %}
{% load i18n %}

{% block content %}
{% if messages %}
 {% for message in messages %}
  <h1>{{ message }}</h1>
  <p>{{ description }}
 {% endfor %}
{% endif %}
{% endblock %}

