{% load telemeta_tags %}
{% load i18n %}

<h2>{{ country }}</h2>
<p>
<a href="{% url "telemeta-geo-country-items" continent.flatname country.flatname %}">
{{ country.items|resources_num }}
</a>
{% trans "in" %}
<a href="{% url "telemeta-geo-country-collections" continent.flatname country.flatname %}">
{{ country.collections|resources_num }}
</a>
</p>
<!--
{% with country.items.all.ethnic_groups as ethnic_groups %}
{% if ethnic_groups %}
<p>
<b>{% trans "Populations / Social groups" %}:</b>
{{ ethnic_groups|join:', ' }}
</p>
{% endif %}
{% endwith %}
-->
