# -*- coding: utf-8 -*-

"""
Telemeta

U{http://telemeta.org}

@author: Guillaume Pellerin <pellerin@parisson.com>
@author: Paul Brossier <piem@piem.org>
@author: Thomas Fillon <thomas@parisson.com>
@author: Riccardo Zaccarelli <riccardo.zaccarelli@gmail.com>
@author: Olivier Guilyardi <olivier@samalyse.com>
@author: David Lipszyc <davidlipszyc@gmail.com>
@author: Thomas Fillon <thomas.fillon@parisson.com>
"""

__docformat__ = 'epytext en'
__version__ = '1.6'
__url__ = 'http://telemeta.org'
__copyright__ = '(C) 2006-2016 Parisson SARL'
__license__ = 'AGPLv3'
__license_long__ = """
Copyright (C) Parisson SARL (2006-2016)

This file is part of Telemeta.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""
