ALTER TABLE `vernacular_styles` ENGINE=InnoDB;
ALTER TABLE `users` ENGINE=InnoDB;
ALTER TABLE `thumbnail_kvstore` ENGINE=InnoDB;
ALTER TABLE `telemeta_media_transcoded` ENGINE=InnoDB;
ALTER TABLE `tape_width` ENGINE=InnoDB;
ALTER TABLE `tape_wheel_diameter` ENGINE=InnoDB;
ALTER TABLE `tape_vendor` ENGINE=InnoDB;
ALTER TABLE `tape_speed` ENGINE=InnoDB;
ALTER TABLE `tape_length` ENGINE=InnoDB;
ALTER TABLE `south_migrationhistory` ENGINE=InnoDB;
ALTER TABLE `search_criteria` ENGINE=InnoDB;
ALTER TABLE `searches_criteria` ENGINE=InnoDB;
ALTER TABLE `searches` ENGINE=InnoDB;
ALTER TABLE `rights` ENGINE=InnoDB;
ALTER TABLE `revisions` ENGINE=InnoDB;
ALTER TABLE `recording_contexts` ENGINE=InnoDB;
ALTER TABLE `publishing_status` ENGINE=InnoDB;
ALTER TABLE `publisher_collections` ENGINE=InnoDB;
ALTER TABLE `publishers` ENGINE=InnoDB;
ALTER TABLE `profiles` ENGINE=InnoDB;
ALTER TABLE `playlist_resources` ENGINE=InnoDB;
ALTER TABLE `playlists` ENGINE=InnoDB;
ALTER TABLE `physical_formats` ENGINE=InnoDB;
ALTER TABLE `original_format` ENGINE=InnoDB;
ALTER TABLE `original_channel_number` ENGINE=InnoDB;
ALTER TABLE `organization` ENGINE=InnoDB;
ALTER TABLE `metadata_writers` ENGINE=InnoDB;
ALTER TABLE `metadata_authors` ENGINE=InnoDB;
ALTER TABLE `media_type` ENGINE=InnoDB;
ALTER TABLE `media_transcoding` ENGINE=InnoDB;
ALTER TABLE `media_status` ENGINE=InnoDB;
ALTER TABLE `media_parts` ENGINE=InnoDB;
ALTER TABLE `media_markers` ENGINE=InnoDB;
ALTER TABLE `media_item_related` ENGINE=InnoDB;
ALTER TABLE `media_item_performances` ENGINE=InnoDB;
ALTER TABLE `media_item_keywords` ENGINE=InnoDB;
ALTER TABLE `media_item_identifier` ENGINE=InnoDB;
ALTER TABLE `media_items` ENGINE=InnoDB;
ALTER TABLE `media_formats` ENGINE=InnoDB;
ALTER TABLE `media_fonds_related` ENGINE=InnoDB;
ALTER TABLE `media_fonds_children` ENGINE=InnoDB;
ALTER TABLE `media_fonds` ENGINE=InnoDB;
ALTER TABLE `media_corpus_related` ENGINE=InnoDB;
ALTER TABLE `media_corpus_children` ENGINE=InnoDB;
ALTER TABLE `media_corpus` ENGINE=InnoDB;
ALTER TABLE `media_collection_related` ENGINE=InnoDB;
ALTER TABLE `media_collection_identifier` ENGINE=InnoDB;
ALTER TABLE `media_collections` ENGINE=InnoDB;
ALTER TABLE `media_analysis` ENGINE=InnoDB;
ALTER TABLE `location_types` ENGINE=InnoDB;
ALTER TABLE `location_relations` ENGINE=InnoDB;
ALTER TABLE `location_aliases` ENGINE=InnoDB;
ALTER TABLE `locations` ENGINE=InnoDB;
ALTER TABLE `legal_rights` ENGINE=InnoDB;
ALTER TABLE `languages` ENGINE=InnoDB;
ALTER TABLE `jqchat_room` ENGINE=InnoDB;
ALTER TABLE `jqchat_message` ENGINE=InnoDB;
ALTER TABLE `ipauth_range` ENGINE=InnoDB;
ALTER TABLE `instrument_relations` ENGINE=InnoDB;
ALTER TABLE `instrument_alias_relations` ENGINE=InnoDB;
ALTER TABLE `instrument_aliases` ENGINE=InnoDB;
ALTER TABLE `instruments` ENGINE=InnoDB;
ALTER TABLE `identifier_type` ENGINE=InnoDB;
ALTER TABLE `googletools_siteverificationcode` ENGINE=InnoDB;
ALTER TABLE `googletools_analyticscode` ENGINE=InnoDB;
ALTER TABLE `generic_styles` ENGINE=InnoDB;
ALTER TABLE `ethnic_group_aliases` ENGINE=InnoDB;
ALTER TABLE `ethnic_groups` ENGINE=InnoDB;
ALTER TABLE `django_site` ENGINE=InnoDB;
ALTER TABLE `django_session` ENGINE=InnoDB;
ALTER TABLE `django_content_type` ENGINE=InnoDB;
ALTER TABLE `django_admin_log` ENGINE=InnoDB;
ALTER TABLE `copy_type` ENGINE=InnoDB;
ALTER TABLE `context_keywords` ENGINE=InnoDB;
ALTER TABLE `auth_user_user_permissions` ENGINE=InnoDB;
ALTER TABLE `auth_user_groups` ENGINE=InnoDB;
ALTER TABLE `auth_user` ENGINE=InnoDB;
ALTER TABLE `auth_permission` ENGINE=InnoDB;
ALTER TABLE `auth_message` ENGINE=InnoDB;
ALTER TABLE `auth_group_permissions` ENGINE=InnoDB;
ALTER TABLE `auth_group` ENGINE=InnoDB;
ALTER TABLE `ad_conversions` ENGINE=InnoDB;
ALTER TABLE `acquisition_modes` ENGINE=InnoDB;
