
#player_maximized .ts-player .ts-wave,  #player_maximized .ts-player .ts-image {
    height: 170px;
}

.ts-skin-lab .ts-player .ts-control {
    background: url('../images/player_controlbg.png');
}

#player_maximized, #player_minimized {
    position: relative;
}


#player_maximized .toggle, #player_minimized .toggle {
    position: relative;
    display: block;
    overflow: hidden;
    float: left;
    width: 18px;
    padding: 10px 0 0 0;
    height: 0px !important;
    height /**/:10px; /* for IE5/Win only */
    background-image: url('../images/maximize.png');
    text-decoration: none;
    border: none;
}

#player_maximized .toggle:hover, #player_minimized .toggle:hover {
    background-position: 0px -10px;
}

#player_maximized .embed_player_frame, #player_minimized .embed_player_frame {
    float: right;
    font-weight: bold;
    color: #6A0307;
    text-decoration: none;
    font-size: 50%;
    padding-left: 2ex;
    padding-right: 2ex;
     position: relative;
    top: -1px;
    line-height: 1.5em;
}

#player_maximized .embed_player_frame:hover, #player_minimized .embed_player_frame:hover {
    text-decoration: none;
}

#player_maximized {
    margin: 10px 0 15px 0;
    display: none;
}