{% extends "postman/base_write.html" %}
{% load i18n %}
{% block pm_write_title %}{% trans "Reply"%}{% endblock %}
{% block pm_write_recipient %}<tr><th><label>{% trans "Recipient" %}:</label></th><td>{{ recipient }}</td></tr>{% endblock %}