{% extends "telemeta/collection_edit.html" %}
{% load i18n %}
{% load telemeta_tags %}

{% block title %}
    <img src="{{ STATIC_URL }}telemeta/images/collections_red.png" style="vertical-align:middle" /> Collection : {% trans "New" %}
{% endblock %}

    {% block cancel %}
    <a id="cancel" href="{% url "telemeta-collections" %}">
      <button type="button" class="btn btn-default">
        <span class="glyphicon glyphicon-remove"></span> {% trans "Cancel" %}
      </button>
    </a>
    {% endblock %}

     {% block cancel2 %}
     <a id="cancel" href="{% url "telemeta-collections" %}">
      <button type="button" class="btn btn-default">
        <span class="glyphicon glyphicon-remove"></span> {% trans "Cancel" %}
      </button>
     </a>
     {% endblock %}

