# -*- coding: utf-8 -*-
# Copyright (C) 2010-2012 Parisson SARL

# This file is part of Telemeta.

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Authors: Guillaume Pellerin <yomguy@parisson.com>

from telemeta.views.home import *
from telemeta.views.item import *
from telemeta.views.collection import *
from telemeta.views.admin import *
from telemeta.views.instrument import *
from telemeta.views.geo import *
from telemeta.views.marker import *
from telemeta.views.playlist import *
from telemeta.views.profile import *
from telemeta.views.feed import *
from telemeta.views.resource import *
from telemeta.views.epub import *
from telemeta.views.search import *
from telemeta.views.new_playlist import *
