{% extends "telemeta/admin.html" %}
{% load i18n %}

{% block extra_javascript %}
{{ block.super }}
<script src="{{ STATIC_URL }}telemeta/js/jquery.iframe-auto-height.plugin.1.9.5.min.js" type="text/javascript"
></script>
<script src="{{ STATIC_URL }}telemeta/js/jquery.browser.js" type="text/javascript"></script>
{% endblock %}

{% block title %}
{% endblock %}

{% block tabcontents %}
 <iframe align="middle" frameborder="0" width="100%" src="{% url "telemeta-home" %}admin/django/"></iframe>

 <script type='text/javascript'>
	 $('iframe').iframeAutoHeight();
 </script>

{% endblock %}
