{% extends "telemeta/base.html" %}
{% load i18n %}

{% block content %}

<p>{% trans "Thanks for spending some quality time with the Web site today." %}</p>

<p><a href="../">{% trans 'Log in again' %}</a></p>

{% endblock %}
