{% extends "telemeta/resource_detail.html" %}
{% load telemeta_tags %}
{% load i18n %}

{% if item %}

{% block content %}
{% with resource|to_dublincore as resource %}
{% include "telemeta/inc/dublincore.html" %}
{% endwith %}

    {% block dublincore %}
    <a href="{% url "telemeta-resource-detail" type resource.public_id %}" style="float:left;margin-top:0.5em;margin-bottom:1em">
      <button type="button" class="btn btn-default">
         <span class="glyphicon glyphicon-arrow-left"></span> {% trans "Normal View" %}
      </button>
    </a>
    {% endblock dublincore %}

{% endblock %}

{% block delete %}
{% if user.is_authenticated and perms.telemeta.delete_mediaresource %}
    <a href="#" onclick="if(confirm(gettrans('delete the resource permanently?'))){window.location.href='{% url "telemeta-resource-delete" type resource.public_id %}';};return false;" style="float:right;margin-top:0.5em;margin-bottom:1em">
      <button type="button" class="btn btn-default">
        <span class="glyphicon glyphicon-trash"></span> {% trans "Delete" %}
      </button>
    </a>
{% endif %}
{% endblock delete %}

{% else %}
    <p>{% trans "No such resource" %}</p>
{% endif %}




{% block related %}
{% endblock related %}
