{% load i18n %}{% trans "Greetings" %} {% if user.get_full_name %}{{ user.get_full_name }}{% else %}{{ user }}{% endif %},

{% blocktrans %}You are receiving this email because you (or someone pretending to be you)
requested that your password be reset on the {{ domain }} site.  If you do not 
wish to reset your password, please ignore this message.

To reset your password, please click the following link, or copy and paste it
into your web browser:{% endblocktrans %}

{{ protocol }}://{{ domain }}{% url 'auth_password_reset_confirm' uid token %}

{% blocktrans with username=user.username %}
Your username, in case you've forgotten: {{ username }}

Best regards,
{{ site_name }} Management
{% endblocktrans %}