{% extends "telemeta/admin.html" %}
{% load telemeta_tags %}
{% load i18n %}

{% block tabcontents %}
 <h4>{% trans "Users" %}</h4>

 {% if users %}
  {% include "telemeta/inc/user_list.html" %}
 {% else %}
    <p class="help">{% trans "No users" %}</p>
 {% endif %}

{% endblock %}
