{% extends "telemeta/base.html" %}
{% load telemeta_tags %}
{% load i18n %}

{% block content %}
<div class="home-content">
<div id="module-set">

{% block modules %}

<div class="btn-module">
 <center>
  <button type="button" id="btn-black" class="btn btn-default" onclick="location.href='{%url "telemeta-fullaccess-items"%}'"> <span class="glyphicon glyphicon-play" aria-hidden="true"></span> {% trans "Access to free    public sound items" %}</a></button>
 </center>
</div>

<div class="module">
    <h3><img src="{{ STATIC_URL }}telemeta/images/module_world.png" alt="world" style="vertical-align:middle" />
    {% trans "Geo Navigator" %}</h3>
    <div style="background-color: white;" align="center">
    <a class="image-link" href="{% url "telemeta-geo-continents" %}">
    <img class="map-thumbnail" src="{{ STATIC_URL }}telemeta/images/world2.png" alt="{% trans "Open the geographic navigator" %}"/></a>
    </div>
</div>

<!--
{% with "Last changes" as title %}
{% include "telemeta/inc/module_revisions.html" %}
{% endwith %}
-->

{{ block.super }}
<div id="module" class="module">
    <h3><img src="{{ STATIC_URL }}telemeta/images/module_playlist.png" style="vertical-align:middle" />
    {% trans "Partners" %}</h3><br />
    <div style="background-color: white; padding: 1ex;" align="center">
    <a href="http://www.cnrs.fr" target="_blank"><img class="logo" src="{{ STATIC_URL }}telemeta/images/logo-CNRS.png" alt="CNRS"></a>&nbsp;&nbsp;&nbsp;
    <a href="http://www.culturecommunication.gouv.fr" target="_blank"><img class="logo" src="{{ STATIC_URL }}telemeta/images/logo_mcc_2.png" alt="MCC"></a>&nbsp;&nbsp;
    <a href="http://www.mnhn.fr" target="_blank"><img class="logo" src="{{ STATIC_URL }}telemeta/images/logo-MNHN.png" alt="MNHN"></a>
    <a href="https://www.u-paris10.fr" target="_blank"><img class="logo" src="{{ STATIC_URL }}telemeta/images/Logo_UPX.png" alt="Université Paris Ouest"></a>
    <br /><br />
    <a href="http://www.parisson.com" target="_blank"><img class="logo" src="{{ STATIC_URL }}telemeta/images/parisson_logo_125_72.png" alt="Parisson"></a>
    <a href="http://www.huma-num.fr" target="_blank"><img class="logo" src="{{ STATIC_URL }}telemeta/images/logohumanum.png" alt="Huma-Num"></a>
    <a href="http://http://www.europeanasounds.eu/" target="_blank"><img class="logo" src="{{ STATIC_URL }}telemeta/images/Europeana_sounds_landscape_2.jpg" alt="Europeana sounds"></a>
    </div>
</div>

{% endblock %}

</div>
<div class="home-description">
<img class="align-left" src="{{ STATIC_URL }}telemeta/images/vox.png" alt="vox" style="vertical-align:middle;" />

{{ page_content|render_flatpage }}
</div>

{% if sound_pub_items %}
<div style="margin-top: 1ex;font-size: 90%; width: 66%;">
<div>
<h1><img src="{{ STATIC_URL }}telemeta/images/playlist_title.png" alt="playlists" style="vertical-align:middle" />
    {% trans "Musical selection" %}</h1>
</div>
{% for item in sound_pub_items %}
<div style="float: left; margin: 3px; width: 48%" align="center"><a href="{% url "telemeta-item-detail" item.public_id %}">{{ item }}</a>{% if item.alt_title %} ({{ item.alt_title }}){% endif %}<br /><span style="font-size: 80%">{{ item.location.fullnames|to_string }}</span><br />
<iframe width='376' height='220' frameborder='0' scrolling='no' marginheight='0' marginwidth='0' src='/archives/items/{{ item.public_id }}/player/362x130/'></iframe></div>
{% endfor %}
</div>
{% endif %}

</div>
{% endblock %}
